@@ -9,15 +9,16 @@
 #define BOTAN_COMPRESSION_TRANSFORM_H__
 
 #include <botan/secmem.h>
-#include <botan/scan_name.h>
+#include <string>
 
 namespace Botan {
 
+/*
+* Interface for a compression algorithm.
+*/
 class BOTAN_DLL Compression_Algorithm
    {
    public:
-      typedef SCAN_Name Spec;
-
       /**
       * Begin compressing. Most compression algorithms offer a tunable
       * time/compression tradeoff parameter generally represented by
@@ -30,7 +31,7 @@ class BOTAN_DLL Compression_Algorithm
 
       /**
       * Process some data. Input must be in size update_granularity() byte blocks.
-      * @param blocks in/out parameter which will possibly be resized or swapped
+      * @param buf in/out parameter which will possibly be resized or swapped
       * @param offset an offset into blocks to begin processing
       * @param flush if true the compressor will be told to flush state
       */
@@ -44,6 +45,9 @@ class BOTAN_DLL Compression_Algorithm
       */
       virtual void finish(secure_vector<byte>& final_block, size_t offset = 0) = 0;
 
+      /**
+      * @return name of the compression algorithm
+      */
       virtual std::string name() const = 0;
 
       /**
@@ -55,22 +59,42 @@ class BOTAN_DLL Compression_Algorithm
       virtual ~Compression_Algorithm() {}
    };
 
+/*
+* Interface for a decompression algorithm.
+*/
 class BOTAN_DLL Decompression_Algorithm
    {
    public:
-      typedef SCAN_Name Spec;
-
       /**
-      * Decompression does not support levels
+      * Begin decompressing.
+      * Decompression does not support levels, as compression does.
       */
       virtual void start() = 0;
 
+      /**
+      * Process some data. Input must be in size update_granularity() byte blocks.
+      * @param buf in/out parameter which will possibly be resized or swapped
+      * @param offset an offset into blocks to begin processing
+      */
       virtual void update(secure_vector<byte>& buf, size_t offset = 0) = 0;
 
+      /**
+      * Finish decompressing
+      *
+      * @param final_block in/out parameter
+      * @param offset an offset into final_block to begin processing
+      */
       virtual void finish(secure_vector<byte>& final_block, size_t offset = 0) = 0;
 
+      /**
+      * @return name of the decompression algorithm
+      */
       virtual std::string name() const = 0;
 
+      /**
+      * Reset the state and abort the current message; start can be
+      * called again to process a new message.
+      */
       virtual void clear() = 0;
 
       virtual ~Decompression_Algorithm() {}
@@ -79,6 +103,9 @@ class BOTAN_DLL Decompression_Algorithm
 BOTAN_DLL Compression_Algorithm* make_compressor(const std::string& type);
 BOTAN_DLL Decompression_Algorithm* make_decompressor(const std::string& type);
 
+/**
+* Adapts a zlib style API
+*/
 class Compression_Stream
    {
    public:
@@ -99,6 +126,9 @@ class Compression_Stream
       virtual bool run(u32bit flags) = 0;
    };
 
+/**
+* Used to implement compression using Compression_Stream
+*/
 class Stream_Compression : public Compression_Algorithm
    {
    public:
@@ -119,6 +149,9 @@ class Stream_Compression : public Compression_Algorithm
       std::unique_ptr<Compression_Stream> m_stream;
    };
 
+/**
+* FIXME add doc
+*/
 class Stream_Decompression : public Decompression_Algorithm
    {
    public:
