@@ -23,7 +23,7 @@ class BOTAN_DLL SQL_Database
       class BOTAN_DLL SQL_DB_Error : public Exception
          {
          public:
-            SQL_DB_Error(const std::string& what) : Exception("SQL database", what) {}
+            explicit SQL_DB_Error(const std::string& what) : Exception("SQL database", what) {}
          };
 
       class BOTAN_DLL Statement
@@ -38,6 +38,8 @@ class BOTAN_DLL SQL_Database
 
             virtual void bind(int column, const std::vector<byte>& blob) = 0;
 
+            virtual void bind(int column, const byte* data, size_t len) = 0;
+
             /* Get output */
             virtual std::pair<const byte*, size_t> get_blob(int column) = 0;
 
