@@ -9,6 +9,7 @@
 #define BOTAN_SRP6A_FILES_H__
 
 #include <botan/bigint.h>
+#include <iosfwd>
 #include <string>
 #include <map>
 
@@ -20,12 +21,20 @@ namespace Botan {
 class BOTAN_DLL SRP6_Authenticator_File
    {
    public:
-      /**
-      * @param filename will be opened and processed as a SRP
-      * authenticator file
-      */
-      SRP6_Authenticator_File(const std::string& filename);
 
+      /**
+      * @param input will be read and processed as SRP authenticator file
+      */
+      explicit SRP6_Authenticator_File(std::istream& input);
+
+      /**
+      * Looks up a user in the authenticator file.
+      * @param username user to look up
+      * @param v set to the host's password verifier
+      * @param salt set to the user's salt value
+      * @param group_id set to the user's group value
+      * @return whether a user exists in the authenticator file
+      */
       bool lookup_user(const std::string& username,
                        BigInt& v,
                        std::vector<byte>& salt,
@@ -35,17 +44,22 @@ class BOTAN_DLL SRP6_Authenticator_File
          {
          SRP6_Data() {}
 
-         SRP6_Data(const BigInt& v,
-                   const std::vector<byte>& salt,
-                   const std::string& group_id) :
-            v(v), salt(salt), group_id(group_id) {}
+         SRP6_Data(const BigInt& v_,
+                   const std::vector<byte>& salt_,
+                   const std::string& group_id_) :
+            v(v_), salt(salt_), group_id(group_id_) {}
 
+         // public member variable:
          BigInt v;
+
+         // public member variable:
          std::vector<byte> salt;
+
+         // public member variable:
          std::string group_id;
          };
 
-      std::map<std::string, SRP6_Data> entries;
+      std::map<std::string, SRP6_Data> m_entries;
    };
 
 }
