@@ -10,11 +10,17 @@
 
 #include <botan/asn1_obj.h>
 #include <botan/asn1_oid.h>
+#include <botan/asn1_alt_name.h>
+#include <botan/cert_status.h>
 #include <botan/datastor.h>
+#include <botan/name_constraint.h>
+#include <botan/key_constraint.h>
 #include <botan/crl_ent.h>
 
 namespace Botan {
 
+class X509_Certificate;
+
 /**
 * X.509 Certificate Extension
 */
@@ -24,7 +30,7 @@ class BOTAN_DLL Certificate_Extension
       /**
       * @return OID representing this extension
       */
-      OID oid_of() const;
+      virtual OID oid_of() const;
 
       /**
       * Make a copy of this extension
@@ -46,6 +52,26 @@ class BOTAN_DLL Certificate_Extension
       */
       virtual std::string oid_name() const = 0;
 
+      /*
+      * Callback visited during path validation.
+      *
+      * An extension can implement this callback to inspect
+      * the path during path validation.
+      *
+      * If an error occurs during validation of this extension,
+      * an appropriate status code shall be added to cert_status.
+      *
+      * @param subject Subject certificate that contains this extension
+      * @param issuer Issuer certificate
+      * @param status Certificate validation status codes for subject certificate
+      * @param cert_path Certificate path which is currently validated
+      * @param pos Position of subject certificate in cert_path
+      */
+      virtual void validate(const X509_Certificate& subject, const X509_Certificate& issuer,
+            const std::vector<std::shared_ptr<const X509_Certificate>>& cert_path,
+            std::vector<std::set<Certificate_Status_Code>>& cert_status,
+            size_t pos);
+
       virtual ~Certificate_Extension() {}
    protected:
       friend class Extensions;
@@ -67,16 +93,22 @@ class BOTAN_DLL Extensions : public ASN1_Object
 
       void add(Certificate_Extension* extn, bool critical = false);
 
+      std::vector<std::pair<std::unique_ptr<Certificate_Extension>, bool>> extensions() const;
+
+      std::map<OID, std::pair<std::vector<byte>, bool>> extensions_raw() const;
+
       Extensions& operator=(const Extensions&);
 
       Extensions(const Extensions&);
-      Extensions(bool st = true) : m_throw_on_unknown_critical(st) {}
-      ~Extensions();
-   private:
-      static Certificate_Extension* get_extension(const OID&);
 
-      std::vector<std::pair<Certificate_Extension*, bool> > m_extensions;
+      explicit Extensions(bool st = true) : m_throw_on_unknown_critical(st) {}
+
+   private:
+      static Certificate_Extension* get_extension(const OID&, bool);
+
+      std::vector<std::pair<std::unique_ptr<Certificate_Extension>, bool>> m_extensions;
       bool m_throw_on_unknown_critical;
+      std::map<OID, std::pair<std::vector<byte>, bool>> m_extensions_raw;
    };
 
 namespace Cert_Extension {
@@ -97,6 +129,7 @@ class BOTAN_DLL Basic_Constraints final : public Certificate_Extension
 
       bool get_is_ca() const { return m_is_ca; }
       size_t get_path_limit() const;
+
    private:
       std::string oid_name() const override
          { return "X509v3.BasicConstraints"; }
@@ -117,9 +150,10 @@ class BOTAN_DLL Key_Usage final : public Certificate_Extension
    public:
       Key_Usage* copy() const override { return new Key_Usage(m_constraints); }
 
-      Key_Usage(Key_Constraints c = NO_CONSTRAINTS) : m_constraints(c) {}
+      explicit Key_Usage(Key_Constraints c = NO_CONSTRAINTS) : m_constraints(c) {}
 
       Key_Constraints get_constraints() const { return m_constraints; }
+
    private:
       std::string oid_name() const override { return "X509v3.KeyUsage"; }
 
@@ -142,7 +176,7 @@ class BOTAN_DLL Subject_Key_ID final : public Certificate_Extension
          { return new Subject_Key_ID(m_key_id); }
 
       Subject_Key_ID() {}
-      Subject_Key_ID(const std::vector<byte>&);
+      explicit Subject_Key_ID(const std::vector<byte>&);
 
       std::vector<byte> get_key_id() const { return m_key_id; }
    private:
@@ -167,9 +201,10 @@ class BOTAN_DLL Authority_Key_ID final : public Certificate_Extension
          { return new Authority_Key_ID(m_key_id); }
 
       Authority_Key_ID() {}
-      Authority_Key_ID(const std::vector<byte>& k) : m_key_id(k) {}
+      explicit Authority_Key_ID(const std::vector<byte>& k) : m_key_id(k) {}
 
       std::vector<byte> get_key_id() const { return m_key_id; }
+
    private:
       std::string oid_name() const override
          { return "X509v3.AuthorityKeyIdentifier"; }
@@ -194,6 +229,7 @@ class BOTAN_DLL Alternative_Name : public Certificate_Extension
       Alternative_Name(const AlternativeName&, const std::string& oid_name);
 
       Alternative_Name(const std::string&, const std::string&);
+
    private:
       std::string oid_name() const override { return m_oid_name_str; }
 
@@ -215,7 +251,7 @@ class BOTAN_DLL Subject_Alternative_Name : public Alternative_Name
       Subject_Alternative_Name* copy() const override
          { return new Subject_Alternative_Name(get_alt_name()); }
 
-      Subject_Alternative_Name(const AlternativeName& = AlternativeName());
+      explicit Subject_Alternative_Name(const AlternativeName& = AlternativeName());
    };
 
 /**
@@ -227,7 +263,7 @@ class BOTAN_DLL Issuer_Alternative_Name : public Alternative_Name
       Issuer_Alternative_Name* copy() const override
          { return new Issuer_Alternative_Name(get_alt_name()); }
 
-      Issuer_Alternative_Name(const AlternativeName& = AlternativeName());
+      explicit Issuer_Alternative_Name(const AlternativeName& = AlternativeName());
    };
 
 /**
@@ -240,9 +276,10 @@ class BOTAN_DLL Extended_Key_Usage final : public Certificate_Extension
          { return new Extended_Key_Usage(m_oids); }
 
       Extended_Key_Usage() {}
-      Extended_Key_Usage(const std::vector<OID>& o) : m_oids(o) {}
+      explicit Extended_Key_Usage(const std::vector<OID>& o) : m_oids(o) {}
 
       std::vector<OID> get_oids() const { return m_oids; }
+
    private:
       std::string oid_name() const override
          { return "X509v3.ExtendedKeyUsage"; }
@@ -255,6 +292,35 @@ class BOTAN_DLL Extended_Key_Usage final : public Certificate_Extension
       std::vector<OID> m_oids;
    };
 
+/**
+* Name Constraints
+*/
+class BOTAN_DLL Name_Constraints : public Certificate_Extension
+   {
+   public:
+      Name_Constraints* copy() const override
+         { return new Name_Constraints(m_name_constraints); }
+
+      Name_Constraints() {}
+      Name_Constraints(const NameConstraints &nc) : m_name_constraints(nc) {}
+
+      void validate(const X509_Certificate& subject, const X509_Certificate& issuer,
+            const std::vector<std::shared_ptr<const X509_Certificate>>& cert_path,
+            std::vector<std::set<Certificate_Status_Code>>& cert_status,
+            size_t pos) override;
+
+   private:
+      std::string oid_name() const override
+         { return "X509v3.NameConstraints"; }
+
+      bool should_encode() const override { return true; }
+      std::vector<byte> encode_inner() const override;
+      void decode_inner(const std::vector<byte>&) override;
+      void contents_to(Data_Store&, Data_Store&) const override;
+
+      NameConstraints m_name_constraints;
+   };
+
 /**
 * Certificate Policies Extension
 */
@@ -265,9 +331,10 @@ class BOTAN_DLL Certificate_Policies final : public Certificate_Extension
          { return new Certificate_Policies(m_oids); }
 
       Certificate_Policies() {}
-      Certificate_Policies(const std::vector<OID>& o) : m_oids(o) {}
+      explicit Certificate_Policies(const std::vector<OID>& o) : m_oids(o) {}
 
       std::vector<OID> get_oids() const { return m_oids; }
+
    private:
       std::string oid_name() const override
          { return "X509v3.CertificatePolicies"; }
@@ -288,7 +355,7 @@ class BOTAN_DLL Authority_Information_Access final : public Certificate_Extensio
 
       Authority_Information_Access() {}
 
-      Authority_Information_Access(const std::string& ocsp) :
+      explicit Authority_Information_Access(const std::string& ocsp) :
          m_ocsp_responder(ocsp) {}
 
    private:
@@ -317,6 +384,7 @@ class BOTAN_DLL CRL_Number final : public Certificate_Extension
       CRL_Number(size_t n) : m_has_value(true), m_crl_number(n) {}
 
       size_t get_crl_number() const;
+
    private:
       std::string oid_name() const override { return "X509v3.CRLNumber"; }
 
@@ -338,9 +406,10 @@ class BOTAN_DLL CRL_ReasonCode final : public Certificate_Extension
       CRL_ReasonCode* copy() const override
          { return new CRL_ReasonCode(m_reason); }
 
-      CRL_ReasonCode(CRL_Code r = UNSPECIFIED) : m_reason(r) {}
+      explicit CRL_ReasonCode(CRL_Code r = UNSPECIFIED) : m_reason(r) {}
 
       CRL_Code get_reason() const { return m_reason; }
+
    private:
       std::string oid_name() const override { return "X509v3.ReasonCode"; }
 
@@ -374,7 +443,7 @@ class BOTAN_DLL CRL_Distribution_Points final : public Certificate_Extension
 
       CRL_Distribution_Points() {}
 
-      CRL_Distribution_Points(const std::vector<Distribution_Point>& points) :
+      explicit CRL_Distribution_Points(const std::vector<Distribution_Point>& points) :
          m_distribution_points(points) {}
 
       std::vector<Distribution_Point> distribution_points() const
@@ -394,6 +463,41 @@ class BOTAN_DLL CRL_Distribution_Points final : public Certificate_Extension
       std::vector<Distribution_Point> m_distribution_points;
    };
 
+/**
+* An unknown X.509 extension marked as critical
+* Will always add a failure to the path validation result.
+*/
+class BOTAN_DLL Unknown_Critical_Extension final : public Certificate_Extension
+   {
+   public:
+      explicit Unknown_Critical_Extension(OID oid) : m_oid(oid) {}
+
+      Unknown_Critical_Extension* copy() const override
+         { return new Unknown_Critical_Extension(m_oid); }
+
+      OID oid_of() const override
+         { return m_oid; };
+
+      void validate(const X509_Certificate&, const X509_Certificate&,
+      		const std::vector<std::shared_ptr<const X509_Certificate>>&,
+      		std::vector<std::set<Certificate_Status_Code>>& cert_status,
+      		size_t pos) override
+         {
+         cert_status.at(pos).insert(Certificate_Status_Code::UNKNOWN_CRITICAL_EXTENSION);
+         }
+
+   private:
+      std::string oid_name() const override
+         { return "Unknown OID name"; }
+
+      bool should_encode() const override { return false; }
+      std::vector<byte> encode_inner() const override;
+      void decode_inner(const std::vector<byte>&) override;
+      void contents_to(Data_Store&, Data_Store&) const override;
+
+      OID m_oid;
+   };
+
 }
 
 }
